@@ -4,7 +4,9 @@ pub use defaults::*;
 mod dht_arc;
 pub use dht_arc::*;
 
+#[cfg(any(test, feature = "test_utils"))]
 mod dht_arc_bucket;
+#[cfg(any(test, feature = "test_utils"))]
 pub use dht_arc_bucket::*;
 
 mod dht_arc_redundancy;
@@ -13,6 +15,9 @@ pub use dht_arc_redundancy::*;
 mod dht_arc_set;
 pub use dht_arc_set::*;
 
+mod dht_location;
+pub use dht_location::*;
+
 mod peer_view;
 pub use peer_view::*;
 
